==> icons-vue-0.6.0.tgz: package/es/watson-health/window--overlay/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../_rollupPluginBabelHelpers-8169a350.js';
import { getAttributes } from '@rocketsoftware/icon-helpers';

var virtual_WatsonHealthWindowOverlay20 = {
  name: 'WatsonHealthWindowOverlay20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "6"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "25",
        "y": "17"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "15",
        "y": "27"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "4",
        "y": "17"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "7.55",
        "y": "9.03",
        "transform": "rotate(-45 8.558 10.545)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "21.96",
        "y": "9.54",
        "transform": "rotate(-45 23.466 10.54)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "2",
        "height": "3",
        "x": "22.46",
        "y": "23.94",
        "transform": "rotate(-45 23.459 25.443)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "3",
        "height": "2",
        "x": "7.04",
        "y": "24.45",
        "transform": "rotate(-45 8.55 25.448)"
      }
    }), createElement('rect', {
      attrs: {
        "width": "24",
        "height": "2",
        "x": "4",
        "y": "2"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,24a6,6,0,1,0-6-6A6,6,0,0,0,16,24Zm0-10v8a4,4,0,0,1,0-8Z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowOverlay20;

==> icons-vue-10.6.1.tgz: package/es/watson-health/window--overlay/20.js <==
import { _ as _objectSpread2, a as _defineProperty } from '../../chunk-75bb93d0.js';
import { getAttributes } from '@carbon/icon-helpers';

var virtual_WatsonHealthWindowOverlay20 = {
  name: 'WatsonHealthWindowOverlay20',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = getAttributes(_objectSpread2({
      width: '20',
      height: '20',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 6h2v3h-2zm10 11h3v2h-3zM15 27h2v3h-2zM4 17h3v2H4zm2.774-6.814l1.414-1.414 2.122 2.122-1.415 1.414zm14.92.712l2.121-2.122 1.415 1.415-2.122 2.121zm-.004 14.189l1.414-1.415 2.121 2.122-1.414 1.414zm-14.913.723l2.12-2.121 1.415 1.414-2.121 2.121zM4 2h24v2H4zm12 22a6 6 0 1 0-6-6 6 6 0 0 0 6 6zm0-10v8a4 4 0 0 1 0-8z"
      }
    }), children]);
  }
};

export default virtual_WatsonHealthWindowOverlay20;
